pub struct Bech32;Expand description
Bech32 encoding
Implementations
Sourceimpl Bech32
impl Bech32
Sourcepub fn decode(s: &str, hrp: &str) -> FastCryptoResult<Vec<u8>>
pub fn decode(s: &str, hrp: &str) -> FastCryptoResult<Vec<u8>>
Decodes the Bech32 string to bytes, validating the given human readable part (hrp). See spec: https://github.com/bitcoin/bips/blob/master/bip-0173.mediawiki
Example:
use vrf_wasm::Bech32;
let bytes = Bech32::decode("split1qqqqsk5gh5","split").unwrap();
assert_eq!(bytes, vec![0, 0]);Sourcepub fn encode<T: AsRef<[u8]>>(data: T, hrp: &str) -> FastCryptoResult<String>
pub fn encode<T: AsRef<[u8]>>(data: T, hrp: &str) -> FastCryptoResult<String>
Encodes bytes into a Bech32 encoded string, with the given human readable part (hrp). See spec: https://github.com/bitcoin/bips/blob/master/bip-0173.mediawiki
Example:
use vrf_wasm::Bech32;
let str = Bech32::encode(vec![0, 0],"split").unwrap();
assert_eq!(str, "split1qqqqsk5gh5".to_string());Auto Trait Implementations
impl Freeze for Bech32
impl RefUnwindSafe for Bech32
impl Send for Bech32
impl Sync for Bech32
impl Unpin for Bech32
impl UnsafeUnpin for Bech32
impl UnwindSafe for Bech32