EllipticCurveMultisetHash

Struct EllipticCurveMultisetHash 

pub struct EllipticCurveMultisetHash { /* private fields */ }
EllipticCurveMultisetHash (ECMH) is a homomorphic multiset hash function. Concretely, each element is mapped to a point on an elliptic curve on which the DL problem is hard (the Ristretto group in Curve25519), and the hash is the sum of all such points.

For more information about the construction of ECMH and its security, see “Elliptic Curve Multiset Hash” by J. Maitin-Shepard et al..

Under the hood, it uses an Ristretto-flavoured Elligator 2 map to map a Sha512 hash of the provided data into points in the Ristretto group, and Sha256 to construct a digest from a serialization of the resulting RistrettoPoint, so digests are 32 bytes long.